<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Interface graphique pour l’application de divers réglages utiles</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>lance l’ajustement de la luminosité dans la barre d’état système « systray »</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>s’ouvre avec l’onglet d’affichage ouvert. Valable uniquement avec le bureau Xfce en cours d’exécution</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Ouvre l’onglet thème directement. Disponible pour les bureaux Xfce et Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Display additional debug output in console</source>
        <translation>Afficher une sortie de débogage supplémentaire dans la console</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Ouvre directement l’onglet « Autre ». Valable sur tous les bureaux</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Fenêtre principale</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Luminosité (logiciel xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Étiquette de texte</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Rétroéclairage matériel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX Ajustements - MX Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="60"/>
        <location filename="../defaultlook.cpp" line="108"/>
        <location filename="../defaultlook.cpp" line="672"/>
        <location filename="../defaultlook.cpp" line="691"/>
        <location filename="../defaultlook.cpp" line="700"/>
        <location filename="../defaultlook.cpp" line="747"/>
        <location filename="../defaultlook.cpp" line="755"/>
        <location filename="../defaultlook.cpp" line="782"/>
        <location filename="../defaultlook.cpp" line="785"/>
        <source>MX Tweak</source>
        <translation>MX Ajustements - MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>Xfce Settings</source>
        <translation>Paramètres de Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="107"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="118"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="135"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="138"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="165"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personnaliser le tableau de bord&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="175"/>
        <location filename="../defaultlook.ui" line="259"/>
        <source>Panel</source>
        <translation>Tableau de bord</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="195"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configurer le comportement des fenêtres et les raccourcis&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="209"/>
        <source>Window Manager</source>
        <translation>Gestionnaire des fenêtres</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="229"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personnaliser l’apparence de votre bureau&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="270"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>Afficher le tableau de bord horizontalement</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="287"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="294"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Effets sur tous les tableaux de bord&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="314"/>
        <location filename="../defaultlook.ui" line="1798"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="319"/>
        <location filename="../defaultlook.ui" line="1808"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="334"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>Afficher le tableau de bord verticalement</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="349"/>
        <location filename="../defaultlook.ui" line="1787"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>Effets sur le 1er tableau de bord</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="356"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Plugin du panneau mise à l’échelle&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="376"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>Enregistrer la configuration actuelle du tableau de bord</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="386"/>
        <location filename="../defaultlook.ui" line="446"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="406"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Gestionnaire d’alimentation</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="413"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>Restaurer la configuration sauvegardée du tableau de bord</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="436"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>Régler les mises à l’échelle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <location filename="../defaultlook.ui" line="1803"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="471"/>
        <location filename="../defaultlook.ui" line="1813"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Boutons des fenêtres&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="500"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike est le plugin du dock moderne pour le tableau de bord.  La fenêtre des boutons est la tasklist classique sans les fonctions du dock.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <location filename="../defaultlook.ui" line="722"/>
        <location filename="../defaultlook.ui" line="896"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1078"/>
        <location filename="../defaultlook.ui" line="1145"/>
        <location filename="../defaultlook.ui" line="1290"/>
        <location filename="../defaultlook.ui" line="1839"/>
        <location filename="../defaultlook.ui" line="1898"/>
        <location filename="../defaultlook.ui" line="2045"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>Rétablir le tableau de bord par défaut</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="553"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>Régler le plugin Tasklist sur&#xa0;:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>Theme</source>
        <translation>Thème</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Remove User Theme Set</source>
        <translation>Supprimer le jeu de thème de l’utilisateur</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="593"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Enregistrer réglages actuels comme un jeu de thème</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="604"/>
        <source>default</source>
        <extracomment>default pointer size determined by X server</extracomment>
        <translation>par défaut</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Thèmes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="624"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icônes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="631"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Curseurs&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Size</source>
        <extracomment>size of the mouse pointer or cursor</extracomment>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Gestionnaire de fenêtres&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Theme Options</source>
        <translation>Options du thème</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="682"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="745"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation>Compositeur</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Transparency and shadow options</source>
        <translation>Options de transparence et d’ombrage</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="783"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="788"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositeur Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="793"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="802"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="807"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="812"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="817"/>
        <location filename="../defaultlook.ui" line="1403"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>arrêt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Modifier le mode VBlank pourrait aider à atténuer certains problèmes de déchirure d’écran.  Consulter l’aide pour plus d’information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="841"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="848"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Lancer l’outil de configuration compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="851"/>
        <source>Compton settings</source>
        <translation>Paramètres de Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Éditer compton.conf directement dans un éditeur de texte</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="865"/>
        <source>Edit compton.conf</source>
        <translation>Éditer compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="876"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paramètres du compositeur de Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="879"/>
        <source>Xfwm Settings</source>
        <translation>Paramètres de Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="919"/>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Rétroéclairage matériel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="937"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajustements de l’affichage&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="964"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Choix de l’affichage pour les ajustements de xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>Resolution</source>
        <translation>Définition</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="981"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;L’enregistrement se fait par écran&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Luminosité logiciel (xrandr)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <location filename="../defaultlook.ui" line="1095"/>
        <source>TextLabel</source>
        <translation>Étiquette de texte</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1005"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Mise à l’échelle GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1025"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Mise à l’échelle xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Config Options</source>
        <translation>Options de configuration</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1132"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Désactiver l’abréviation des noms de fichiers longs sur le bureau</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1156"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   note&#xa0;: pour basculer en hibernation, le fichier swap doit être ≥ RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable single-click on desktop</source>
        <translation>Activer le simple clic sur le bureau</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Activer l’hibernation à partir du menu de déconnexion</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1324"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Réinitialisation des actions personnalisées du clic droit de Thunar aux valeurs par défaut du système</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1375"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Activer le simple clic dans le gestionnaire de fichiers Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1636"/>
        <source>Thunar windows always open in split view</source>
        <translation>Les fenêtres de Thunar s’ouvrent toujours en écran divisé</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <location filename="../defaultlook.ui" line="1568"/>
        <source>Thunar split view opens horizontal</source>
        <translation>L’écran divisé de Thunar s’ouvre horizontalement</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Afficher les pourcentages dans les notifications lorsqu’ils sont disponibles</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <source>Enable Desktop Zoom </source>
        <translation>Activer le zoom du bureau</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <location filename="../defaultlook.ui" line="1754"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Afficher les fenêtres de tous les espaces de travail dans le tableau de bord</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Afficher les boutons d’activité de la boîte de dialogue du fichier GTK en bas des boîtes de dialogue</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1246"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(désactive aussi Client Side Decorations / Décorations Côté Client pour les applications Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1259"/>
        <source>Fluxbox</source>
        <translation>Fluxbox </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1271"/>
        <location filename="../defaultlook.ui" line="1611"/>
        <source>On</source>
        <translation>Marche</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1276"/>
        <location filename="../defaultlook.ui" line="1616"/>
        <source>Off</source>
        <translation>Arrêt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1304"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paramètres de la barre d’outils&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Toggle icon captions</source>
        <translation>Basculer les légendes des icônes</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1351"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Réinitialisation du menu Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1368"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1382"/>
        <source>Toggle desktop icons</source>
        <translation>Basculer les icônes du bureau</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <location filename="../defaultlook.ui" line="1413"/>
        <source>Autohide</source>
        <translation>Masquage automatique</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paramètres du dock&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1487"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icônes du bureau&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1561"/>
        <source>Reset DefaultDock</source>
        <translation>Réinitialisation du dock par défaut</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1575"/>
        <source>Manage Tint2 Panel</source>
        <translation>Gérer le panneau Tint2</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1593"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <location filename="../defaultlook.ui" line="1761"/>
        <source>Placement</source>
        <translation>Disposition</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Écran de veille&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1621"/>
        <source>On Hover</source>
        <translation>Au survol de la souris</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <location filename="../defaultlook.ui" line="1721"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Rétablir les valeurs par défaut&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1650"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ajouter de nouveaux éléments au menu par défaut, le cas échéant, au menu Fluxbox existant.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>Upgrade existing menu entries</source>
        <translation>Mettre à jour les entrées existantes du menu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>Show Toolbar</source>
        <translation>Afficher la barre d’outils</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1690"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Réinitialiser TOUS les paramètres de mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1697"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Délai (minutes) pour activer la mise en veille de l’écran.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1710"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1768"/>
        <source>Enable single-click</source>
        <translation>Activer le simple clic</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1775"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Réinitialisation des valeurs par défaut de KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1826"/>
        <source>Workspace</source>
        <translation>Espace de travail</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>Utilitaire de notification de la barre d’état système pour le démarrage automatique de la mise à jour de Plasma-Discover</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1860"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Touche logo Windows</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1868"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Choose application&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Choisir une application&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1881"/>
        <source>Xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>Xfce-superkey par défaut</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1888"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Also known as the &amp;quot;windows&amp;quot; key&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Également appelée touche &amp;quot;Windows&amp;quot; &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1891"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Commande à exécuter avec la touche logo Windows (appelée aussi Super ou Meta)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1921"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1929"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requiert un redémarrage&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1932"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Activer les adaptateurs Bluetooth au démarrage</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1939"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Utiliser le pilote Intel à la place du pilote par défaut « modesetting » (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1946"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          NOTE&#xa0;: l’actuelle configuration /etc/X11/xorg.conf.d/20-radeon.conf sera sauvegardée dans le répertoire home</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1953"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Réinitialiser Lightdm (écran de connexion) au thème par défaut du système</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1960"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1970"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Modifier le nom de l’ordinateur (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1977"/>
        <source>Enable kernel sandbox</source>
        <translation>Activer le bac à sable des noyaux</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1984"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Permettre le montage de disques internes par des utilisateurs non root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1991"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Activer les informations de la batterie des appareils Bluetooth connectés (nécessite un redémarrage du système)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1998"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt installe des paquets supplémentaires « recommandés » en tant que dépendances</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2015"/>
        <source>Password for administrative tasks:</source>
        <translation>Mot de passe pour les tâches administratives&#xa0;:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2022"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>marquer un hold (blocage) ou supprimer un hold des mises à jour des noyaux Liquorix</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2025"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Activer les mises à jour automatiques du noyau Liquorix (dépôt MX ahs)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2032"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          NOTE&#xa0;: l’actuelle configuration /etc/X11/xorg.conf.d/20-amd.conf sera sauvegardée dans le répertoire home</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2056"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Utiliser l’option du pilote radeon sans tearing - sans déchirure d’écran</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2063"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Utiliser l’option amdgpu sans tearing - sans déchirure d’écran</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2070"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Modifier le gestionnaire d’affichage par défaut pour l’écran de connexion (login). (Nécessite un redémarrage).</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2077"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Utiliser les décorations côté client (CSD - Client Side Decorations) sur les applications GTK3 qui les supportent (nécessite un redémarrage de session)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2084"/>
        <source>&amp;User</source>
        <translation>&amp;Utilisateur</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2091"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>marquer un hold (blocage) ou supprimer un hold des mises à jour des noyaux Debian</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2094"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Activer les mises à jour automatiques du noyau Debian</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2114"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTE&#xa0;: l’actuelle configuration /etc/X11/xorg.conf.d/20-intel.conf sera sauvegardée dans le dossier home</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2121"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Générer le menu « Toutes les applications » de fluxbox après l’installation, la suppression et les mises à jour des paquets</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2128"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Le chargement anticipé du module KVM est une nouveauté du noyau 6.12 et entre en conflit avec certaines applications de machines virtuelles non KVM, notamment VirtualBox &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2131"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Désactiver le chargement anticipé du module KVM (doit être désactivé pour le fonctionnement de Virtualbox sur le noyau 6.12 et plus)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="61"/>
        <source>--display switch only valid for Xfce</source>
        <translation>-- le changement d’affichage ne marche que pour Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="671"/>
        <source>About MX Tweak</source>
        <translation>À propos de MX Ajustements - MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="673"/>
        <source>Version: </source>
        <translation>Version&#xa0;: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="674"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Application permettant de modifier rapidement le thème de l’interface utilisateur par défaut et d’y apporter des modifications.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="676"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="677"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="691"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="701"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Terminé&#xa0;! Firefox peut nécessiter un redémarrage pour activer les changements.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="748"/>
        <source>Plese remove special characters</source>
        <translation>Veuillez supprimer les caractères spéciaux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="748"/>
        <source>from file name</source>
        <translation>à partir du nom du fichier</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="755"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Le nom du fichier existe déjà. Choisissez un autre nom</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="783"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Le fichier n’est pas un fichier d’archive tar.xz valide</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="786"/>
        <source>Archive does not contain a panel config</source>
        <translation>L’archive ne contient pas de configuration de panneau</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="961"/>
        <source>Panel settings</source>
        <translation>Paramètres du tableau de bord</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="962"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Les paramètres actuels de votre tableau de bord ont été enregistrés dans un dossier caché nommé .restore dans votre dossier home (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1662"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Thèmes Plasma Widget</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1663"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Schémas de couleurs</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1664"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Plasma apparence thèmes généraux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1932"/>
        <source>settings</source>
        <translation>paramètres</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2273"/>
        <source>Choose a theme set</source>
        <translation>Choisir un jeu de thèmes</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2737"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Veuillez entrer le nom de l’ordinateur.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2741"/>
        <source>Sorry, your computer name contains invalid characters.
You&apos;ll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Désolé mais le nom de votre ordinateur contient des caractères non valides. 
Veuillez choisir un nom différent avant de continuer.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="4374"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Sélectionner l’application à exécuter</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Supprimer le jeu de thèmes de l’utilisateur</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nouveau jeu de thèmes</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Entrer un nom pour le nouveau jeu de thèmes</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Boutons des fenêtres</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Apparence&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Afficher le nom des boutons</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Afficher les boutons plats</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Afficher la poignée</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Ordre de tri&#xa0;:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Horodatage</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Titre du groupe et horodatage</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titre du groupe et de la fenêtre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Aucun, autoriser le glisser-déposer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportement&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Groupement de fenêtres&#xa0;:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Toujours</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Action du clic du milieu&#xa0;:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Fermer la fenêtre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimiser la fenêtre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaurer les fenêtres réduites dans l’espace de travail actif</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Afficher le cadre de la fenêtre au survol d’un bouton</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Changer de fenêtre à l’aide de la molette de la souris</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrage&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Afficher les fenêtres de tous les espaces de travail ou fenêtres d’affichage viewports</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Afficher uniquement les fenêtres réduites</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Afficher les fenêtres de tous les moniteurs</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Boîte de dialogue</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Fenêtres contextuelles (popup)</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Fenêtres lors du déplacement</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paramètres d’opacité&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Décors des fenêtres</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Afficher des ombres sous les fenêtres du dock</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Afficher des ombres sous les fenêtres contextuelles (popup)</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Fenêtres lors du redimensionnement</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Afficher des ombres sous les fenêtres régulières</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paramètres de fonction&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Afficher un aperçu des fenêtres plutôt que des icônes lors de l’alternance</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Afficher directement le recouvrement de fenêtres en plein écran</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Fenêtres inactives</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synchroniser le rendu avec le rafraîchissement vertical</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Paramètres du compositeur Xfmw</translation>
    </message>
</context>
</TS>
